//Source file: ClientAppDescription.java
//Date: September 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.8.0

package org.csapi.jr.se.fw;

/**
 * This data type is a Sequence of Data Elements which describes an enterprise client application. It is a structured data type, consisting of a unique 'client application ID', password and a list of client application properties.
Note 1: The HasAccessSession flag indicates if the client application currently has an access session active with the framework and will be returned in describeClientApp ().  This flag will be ignored if it is passed in to createClientApp ().
Note 2: The HasServiceInstances flag indicates if the client application currently has service instances active and will be returned in describeClientApp ().  This flag will be ignored if it is passed in to createClientApp ().  This flag must be false if hasAccessSession is false.
 * 
 */
public final class ClientAppDescription implements java.io.Serializable {

    private String clientAppID;
    private org.csapi.jr.se.fw.Property[] clientAppProperties;
    private boolean hasAccessSession;
    private boolean hasServiceInstances;

    /**
     * Creates a new ClientAppDescription instance.
     */
    public ClientAppDescription () {}

    /**
     * Creates a new ClientAppDescription instance.
     * @param _clientAppID   
     * @param _clientAppProperties   
     * @param _hasAccessSession   
     * @param _hasServiceInstances   
     */
    public ClientAppDescription (String _clientAppID, org.csapi.jr.se.fw.Property[] _clientAppProperties, boolean _hasAccessSession, boolean _hasServiceInstances) {

        this.clientAppID = _clientAppID;
        this.clientAppProperties = _clientAppProperties;
        this.hasAccessSession = _hasAccessSession;
        this.hasServiceInstances = _hasServiceInstances;
    }

    
    /**
     * Creates a new ClientAppDescription instance.
     * @param _clientAppID   
     * @param _clientAppProperties   
     *
     * @deprecated  This method is deprecated and will be removed in a later release.
     * It is strongly recommended not to implement this method. 
    */
    public ClientAppDescription (String _clientAppID, org.csapi.jr.se.fw.Property[] _clientAppProperties) {

        this.clientAppID = _clientAppID;
        this.clientAppProperties = _clientAppProperties;
    }

    /**
     * This method returns a clientAppID.
     * 
     * @return a String value
     */
    public String getClientAppID() {
        return clientAppID;
    }

    /**
     * This method returns a clientAppProperties.
     * 
     * @return a org.csapi.jr.se.fw.Property[] value
     */
    public org.csapi.jr.se.fw.Property[] getClientAppProperties() {
        return clientAppProperties;
    }

    /**
     * This method returns a hasAccessSession.
     * 
     * @return a boolean value
     */
    public boolean getHasAccessSession() {
        return hasAccessSession;
    }

    /**
     * This method returns a hasServiceInstances.
     * 
     * @return a boolean value
     */
    public boolean getHasServiceInstances() {
        return hasServiceInstances;
    }


    /**
     * This method sets a clientAppID.
     */ 
    public void setClientAppID(String clientAppID) {
        this.clientAppID = clientAppID;
    }

    /**
     * This method sets a clientAppProperties.
     */ 
    public void setClientAppProperties(org.csapi.jr.se.fw.Property[] clientAppProperties) {
        this.clientAppProperties = clientAppProperties;
    }

    /**
     * This method sets a hasAccessSession.
     */ 
    public void setHasAccessSession(boolean hasAccessSession) {
        this.hasAccessSession = hasAccessSession;
    }

    /**
     * This method sets a hasServiceInstances.
     */ 
    public void setHasServiceInstances(boolean hasServiceInstances) {
        this.hasServiceInstances = hasServiceInstances;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof ClientAppDescription)) {
            return false;
        } 
        ClientAppDescription clientAppDescription = (ClientAppDescription) o;
        if(!(this.clientAppProperties == clientAppDescription.clientAppProperties))  {
            return false;
        }
        if(!(this.clientAppID == clientAppDescription.clientAppID))  {
            return false;
        }
        if(!(this.hasAccessSession == clientAppDescription.hasAccessSession)) {
            return false;
        }
        if(!(this.hasServiceInstances == clientAppDescription.hasServiceInstances)) {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ClientAppDescription

