//Source file: LoadStatisticError.java
//Date: September 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.8.0

package org.csapi.jr.se.fw;

/**
 * Defines the error code associated with a failed attempt to retrieve any load statistics information. 
 *
 */
public final class LoadStatisticError implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static LoadStatisticError[] _array = new LoadStatisticError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadStatisticError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Undefined error
     */
    public static final int _LOAD_INFO_ERROR_UNDEFINED =  0;

    /**
     * Undefined error
     */
    public static final LoadStatisticError LOAD_INFO_ERROR_UNDEFINED = new LoadStatisticError(_LOAD_INFO_ERROR_UNDEFINED);

    /**
     * Load statistics unavailable
     */
    public static final int _LOAD_INFO_UNAVAILABLE =  1;

    /**
     * Load statistics unavailable
     */
    public static final LoadStatisticError LOAD_INFO_UNAVAILABLE = new LoadStatisticError(_LOAD_INFO_UNAVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LoadStatisticError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadStatisticError object
     */
    public String getValueText() {
        switch (_value) {
            case _LOAD_INFO_ERROR_UNDEFINED:
                return "LOAD_INFO_ERROR_UNDEFINED";
            case _LOAD_INFO_UNAVAILABLE:
                return "LOAD_INFO_UNAVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadStatisticError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LoadStatisticError)) {
            return false;
        }
        LoadStatisticError loadStatisticError = (LoadStatisticError) o; 
        if(!(this.getValue() == loadStatisticError.getValue())) {
            return false;
        }
        if (this.hashCode() != loadStatisticError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadStatisticError

