//Source file: LoadStatusError.java
//Date: September 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.8.0

package org.csapi.jr.se.fw;

/**
 * The error code for getting the load status.
			Undefined error.
			Unable to get the load status.
 *
 */
public final class LoadStatusError implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static LoadStatusError[] _array = new LoadStatusError[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadStatusError(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * 
     */
    public static final int _LOAD_STATUS_ERROR_UNDEFINED =  0;

    /**
     * 
     */
    public static final LoadStatusError LOAD_STATUS_ERROR_UNDEFINED = new LoadStatusError(_LOAD_STATUS_ERROR_UNDEFINED);

    /**
     * 
     */
    public static final int _LOAD_STATUS_ERROR_UNAVAILABLE =  1;

    /**
     * 
     */
    public static final LoadStatusError LOAD_STATUS_ERROR_UNAVAILABLE = new LoadStatusError(_LOAD_STATUS_ERROR_UNAVAILABLE);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved LoadStatusError object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadStatusError object
     */
    public String getValueText() {
        switch (_value) {
            case _LOAD_STATUS_ERROR_UNDEFINED:
                return "LOAD_STATUS_ERROR_UNDEFINED";
            case _LOAD_STATUS_ERROR_UNAVAILABLE:
                return "LOAD_STATUS_ERROR_UNAVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadStatusError getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof LoadStatusError)) {
            return false;
        }
        LoadStatusError loadStatusError = (LoadStatusError) o; 
        if(!(this.getValue() == loadStatusError.getValue())) {
            return false;
        }
        if (this.hashCode() != loadStatusError.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadStatusError

