//Source file: SignatureAndServiceMgr.java
//Date: September 2004
//Framework Data Types for 3GPP TS 29.198-03 V5.8.0

package org.csapi.jr.se.fw;

/**
 * This is a Sequence of Data Elements containing the digital signature of the Framework for the service agreement, and a reference to the SCF manager interface of the SCF.
The digitalSignature contains a CMS (Cryptographic Message Syntax) object (as defined in RFC 2630) with content type Signed-data. The signature is calculated and created as per section 5 of RFC 2630. The content is the agreement text given by the client application. The "external signature" construct shall not be used (that is the eContent field in the EncapsulatedContentInfo field shall be present and contain the agreement text string). The signing-time attribute, as defined in section 11.3 of RFC 2630, shall also be used to provide replay prevention.
The ServiceMgrInterface is a reference to the SCF manager interface for the selected SCF.
 * 
 */
public final class SignatureAndServiceMgr implements java.io.Serializable {

    private byte[] digitalSignature;
    private org.csapi.jr.se.Service serviceMgrInterface;

    /**
     * Creates a new SignatureAndServiceMgr instance.
     */
    public SignatureAndServiceMgr () {}

    /**
     * Creates a new SignatureAndServiceMgr instance.
     * @param _digitalSignature   
     * @param _serviceMgrInterface   
     */
    public SignatureAndServiceMgr (byte[] _digitalSignature, org.csapi.jr.se.Service _serviceMgrInterface) {

        this.digitalSignature = _digitalSignature;
        this.serviceMgrInterface = _serviceMgrInterface;
    }

    /**
     * This method returns a digitalSignature.
     * 
     * @return a byte[] value
     */
    public byte[] getDigitalSignature() {
        return digitalSignature;
    }

    /**
     * This method returns a serviceMgrInterface.
     * 
     * @return a org.csapi.jr.se.Service value
     */
    public org.csapi.jr.se.Service getServiceMgrInterface() {
        return serviceMgrInterface;
    }


    /**
     * This method sets a digitalSignature.
     */ 
    public void setDigitalSignature(byte[] digitalSignature) {
        this.digitalSignature = digitalSignature;
    }

    /**
     * This method sets a serviceMgrInterface.
     */ 
    public void setServiceMgrInterface(org.csapi.jr.se.Service serviceMgrInterface) {
        this.serviceMgrInterface = serviceMgrInterface;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof SignatureAndServiceMgr)) {
            return false;
        } 
        SignatureAndServiceMgr signatureAndServiceMgr = (SignatureAndServiceMgr) o;
        if ((this.serviceMgrInterface != null) && (signatureAndServiceMgr.serviceMgrInterface != null)) {
            if(!(this.serviceMgrInterface.equals(signatureAndServiceMgr.serviceMgrInterface))) {
                return false;
            }
        }
        if(!(this.digitalSignature == signatureAndServiceMgr.digitalSignature))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SignatureAndServiceMgr

