//Source file: SvcHeartBeatMgmt.java
//Date: September 2004
//Framework to Service Interfaces for 3GPP TS 29.198-03 V5.8.0

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * This interface allows the initialisation of a heartbeat supervision of the service instance by the framework.  If the IpSvcHeartBeatMgmt interface is implemented by a Service, as a minimum enableHeartBeat() and disableHeartBeat() shall be implemented.
 *
 */
public interface SvcHeartBeatMgmt extends org.csapi.jr.se.CsapiInterface{

    /**
     * With this method, the framework instructs the service instance to begin sending its heartbeat to the specified interface at the specified interval.
     * @param interval The time interval in milliseconds between the heartbeats.
     * @param CsapiInterface This parameter refers to the callback interface the heartbeat is calling.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @exception org.csapi.jr.se.InvalidInterfaceTypeException     The interface reference supplied by the client is the wrong type.
     */
    void  enableSvcHeartBeat(int interval, org.csapi.jr.se.fw.fw_service.integrity.FwHeartBeat CsapiInterface) throws org.csapi.jr.se.CommonException, org.csapi.jr.se.InvalidInterfaceTypeException;

    /**
     * Instructs the service instance to cease the sending of its heartbeat. 
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  disableSvcHeartBeat() throws org.csapi.jr.se.CommonException;

    /**
     * Allows the administrative change of the heartbeat interval.
     * @param interval The time interval in milliseconds between the heartbeats.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  changeInterval(int interval) throws org.csapi.jr.se.CommonException;


} // SvcHeartBeatMgmt

