//Source file: SvcLoadManager.java
//Date: September 2004
//Framework to Service Interfaces for 3GPP TS 29.198-03 V5.8.0

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * The service developer supplies the load manager service interface to handle requests, reports and other responses from the framework load manager function.  The service instance supplies the identity of its callback interface at the time it obtains the framework's load manager interface, by use of the obtainInterfaceWithCallback() method on the IpAccess interface.																																If the IpSvcLoadManager interface is implemented by a Service, at least one of the methods shall be implemented as a minimum requirement. If load level notifications are supported, then loadLevelNotification() shall be implemented.  If a the Service is capable of invoking the IpFwLoadManager.queryLoadStatsReq() method, then it shall implement queryLoadStatsRes() and queryLoadStatsErr() methods in this interface.
 *
 */
public interface SvcLoadManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method querySvcLoadStatsReq shall be used instead, using the new identifier to correlate requests and responses.
The framework uses this method to request the service instance to provide its load statistic records.
     * @param timeInterval Specifies the time interval for which load statistic records should be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @deprecated
     */
    void  querySvcLoadReq(org.csapi.jr.se.TimeInterval timeInterval) throws org.csapi.jr.se.CommonException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryLoadStatsRes shall be used instead, using the new identifier to correlate requests and responses.
The framework uses this method to send load statistic records back to the service instance that requested the information; that is in response to an invocation of the queryLoadReq method on the IpFwLoadManager interface.
     * @param loadStatistics Specifies the framework-supplied load statistics
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @deprecated
     */
    void  queryLoadRes(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method queryLoadStatsErr shall be used instead, using the new identifier to correlate requests and errors.
The framework uses this method to return an error response to the service that requested the framework's load statistics information, when the framework is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the queryLoadReq method on the IpFwLoadManager interface.
     * @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the framework's load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     * @deprecated
     */
    void  queryLoadErr(org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError) throws org.csapi.jr.se.CommonException;

    /**
     * Upon detecting load condition change, (for example load level changing from 0 to 1, 0 to 2, 1 to 0, for the application or framework which has been registered for load level notifications) this method is invoked on the SCF.  In addition this method shall be invoked on the SCF in order to provide a notification of current load status, when load notifications are first requested, or resumed after suspension.
     * @param loadStatistics Specifies the framework-supplied load statistics, which include the load level change(s).
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  loadLevelNotification(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to request the service instance to suspend sending it any notifications  for example while the framework handles a temporary overload condition.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  suspendNotification() throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to request the service instance to resume sending it notifications  for example after a period of suspension during which the framework handled a temporary overload condition.  Upon receipt of this method the service instance shall inform the framework of the current load using the reportLoad method on the corresponding IpFwLoadManager.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  resumeNotification() throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to register to receive notifications of load level changes associated with the  service instance.  Upon receipt of this method the service instance shall inform the framework of the current load using the reportLoad method on the corresponding IpFwLoadManager.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  createLoadLevelNotification() throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to unregister for notifications of load level changes associated with the service instance.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  destroyLoadLevelNotification() throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to request the service instance to provide its load statistic records. 
     * @param loadStatsReqID The identifier provided by the framework to correlate the response (when it arrives) with this request.
     * @param timeInterval Specifies the time interval for which load statistic records should be reported.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  querySvcLoadStatsReq(int loadStatsReqID, org.csapi.jr.se.TimeInterval timeInterval) throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to send load statistic records back to the service instance that requested the information; that is in response to an invocation of the queryLoadReq method on the IpFwLoadManager interface.
     * @param loadStatsReqID Used by the service instance to correlate this response (when it arrives) with the original request.
     * @param loadStatistics Specifies the framework-supplied load statistics
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  queryLoadStatsRes(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatistic[] loadStatistics) throws org.csapi.jr.se.CommonException;

    /**
     * The framework uses this method to return an error response to the service that requested the framework's load statistics information, when the framework is unsuccessful in obtaining any load statistic records; that is in response to an invocation of the queryLoadReq method on the IpFwLoadManager interface. 
     * @param loadStatsReqID Used by the service instance to correlate this error (when it arrives) with the original request.
     * @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the framework's load statistics.
     * @exception org.csapi.jr.se.CommonException     Defines the structure of the exception class which is applicable to all methods.
     */
    void  queryLoadStatsErr(int loadStatsReqID, org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError) throws org.csapi.jr.se.CommonException;


} // SvcLoadManager

